@@ -31,6 +31,8 @@
 #include "properties.h"
 #include "propertytype.h"
 
+#include <QPointer>
+
 namespace Tiled {
 
 /**
@@ -49,6 +51,7 @@ public:
         WangSetType         = 0x040,
         WangColorType       = 0x080,
         ProjectType         = 0x100,
+        WorldType           = 0x200,
     };
 
     explicit Object(TypeId typeId, const QString &className = QString())
@@ -136,6 +139,18 @@ public:
     void setProperty(const QString &name, const QVariant &value)
     { mProperties.insert(name, value); }
 
+    /**
+     * Sets the value of an object's property identified the given \a path
+     * to \a value.
+     *
+     * The \a path is a list of property names, where each name identifies
+     * a member of the previous member's value. The last name in the list
+     * identifies the property to set.
+     *
+     * Returns whether the property was set.
+     */
+    bool setProperty(const QStringList &path, const QVariant &value);
+
     /**
      * Removes the property with the given \a name.
      */
@@ -152,6 +167,12 @@ private:
     QString mClassName;
     Properties mProperties;
 
+    /**
+     * The editable wrapper created for this object.
+     */
+    QPointer<QObject> mEditable;
+    friend class EditableObject;
+
     static SharedPropertyTypes mPropertyTypes;
 };
 
